.. ngsxfem documentation master file, created by
   copy+paste and changes from ngsxtrefftz.

.. raw:: html

    <style>
        .p-Widget {
            height: 400px;
        }
        .dg.main {
            margin-left: 0px;
        }
        div.p-Widget div div div div.dg ul li {
            list-style: none;
            margin-left: 0px;
        }
        div.p-Widget div div div div.dg ul li div.dg {
            margin-bottom: 0px;
        }
    </style>

.. only:: html
    .. role:: raw-html(raw)
        :format: html

Jupyter tutorials
~~~~~~~~~~~~~~~~~

To work through the i-tutorials we refer to the repository https://github.com/ngsxfem/ngsxfem-jupyter with instructions and **more material**. Here, we give a selection of notebooks. You can run it through binder here: https://mybinder.org/v2/gh/ngsxfem/ngsxfem-jupyter/master?filepath=tutorials.ipynb .

.. toctree::
   :numbered:
   :maxdepth: 1

  basics.ipynb
  intlset.ipynb
  cutfem.ipynb
  spacetime_fitted.ipynb
  spacetime_unfitted.ipynb
  mlset_basic.ipynb
  mlset_pde.ipynb
  aggregation.ipynb
  unfmixed.ipynb
  
